# Installation

The instructions below will help you to properly install the generated package to the lavalite project.

## Location

Extract the package contents to the folder 

`/packages/boomee/education/`

## Composer

Add the below entries in the `composer.json` file's autoload section and run the command `composer dump-autoload` in terminal.

```json

...
     "autoload": {
         ...

        "classmap": [
            ...
            
            "packages/boomee/education/database/seeds",
            
            ...
        ],
        "psr-4": {
            ...
            
            "Boomee\\Education\\": "packages/boomee/education/src",
            
            ...
        }
    },
...

```

## Config

Add the entries in service provider in `config/app.php`

```php

...
    'providers'       => [
        ...
        
        Boomee\Education\Providers\EducationServiceProvider::class,
        
        ...
    ],

    ...

    'alias'             => [
        ...
        
        'Education'  => Boomee\Education\Facades\Education::class,
        
        ...
    ]
...

```

## Migrate

After service provider is set run the commapnd to migrate and seed the database.


    php artisan migrate
    php artisan db:seed --class=Boomee\\EducationTableSeeder

## Publishing


**Publishing configuration**

    php artisan vendor:publish --provider="Boomee\Education\Providers\EducationServiceProvider" --tag="config"

**Publishing language**

    php artisan vendor:publish --provider="Boomee\Education\Providers\EducationServiceProvider" --tag="lang"

**Publishing views**

    php artisan vendor:publish --provider="Boomee\Education\Providers\EducationServiceProvider" --tag="view"


## URLs and APIs


### Web Urls

**Admin**

    http://path-to-route-folder/admin/education/{modulename}

**User**

    http://path-to-route-folder/user/education/{modulename}

**Public**

    http://path-to-route-folder/education


### API endpoints

**List**
 
    http://path-to-route-folder/api/user/education/{modulename}
    METHOD: GET

**Create**

    http://path-to-route-folder/api/user/education/{modulename}
    METHOD: POST

**Edit**

    http://path-to-route-folder/api/user/education/{modulename}/{id}
    METHOD: PUT

**Delete**

    http://path-to-route-folder/api/user/education/{modulename}/{id}
    METHOD: DELETE

**Public List**

    http://path-to-route-folder/api/education/{modulename}
    METHOD: GET

**Public Single**

    http://path-to-route-folder/api/education/{modulename}/{slug}
    METHOD: GET