<?php

namespace Boomee\Education\Http\Controllers;

use App\Http\Controllers\PublicController as BaseController;
use Boomee\Education\Interfaces\EducationRepositoryInterface;

class EducationPublicController extends BaseController
{
    // use EducationWorkflow;

    /**
     * Constructor.
     *
     * @param type \Boomee\Education\Interfaces\EducationRepositoryInterface $education
     *
     * @return type
     */
    public function __construct(EducationRepositoryInterface $education)
    {
        $this->repository = $education;
        parent::__construct();
    }

    /**
     * Show education's list.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function index()
    {
        $education = $this->repository
        ->pushCriteria(app('Litepie\Repository\Criteria\RequestCriteria'))
        ->scopeQuery(function($query){
            return $query->orderBy('id','DESC');
        })->paginate();


        return $this->response->setMetaTitle(trans('education::education.names'))
            ->view('education::public.education.index')
            ->data(compact('education'))
            ->output();
    }


    /**
     * Show education.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function show($slug)
    {
        $education = $this->repository->scopeQuery(function($query) use ($slug) {
            return $query->orderBy('id','DESC')
                         ->where('slug', $slug);
        })->first(['*']);

        return $this->response->setMetaTitle($education->name . trans('education::education.name'))
            ->view('education::public.education.show')
            ->data(compact('education'))
            ->output();
    }

}
