<?php

namespace Boomee\Education\Policies;

use Litepie\User\Contracts\UserPolicy;
use Boomee\Education\Models\Education;

class EducationPolicy
{

    /**
     * Determine if the given user can view the education.
     *
     * @param UserPolicy $user
     * @param Education $education
     *
     * @return bool
     */
    public function view(UserPolicy $user, Education $education)
    {
        if ($user->canDo('education.education.view') && $user->isAdmin()) {
            return true;
        }

        return $education->user_id == user_id() && $education->user_type == user_type();
    }

    /**
     * Determine if the given user can create a education.
     *
     * @param UserPolicy $user
     * @param Education $education
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('education.education.create');
    }

    /**
     * Determine if the given user can update the given education.
     *
     * @param UserPolicy $user
     * @param Education $education
     *
     * @return bool
     */
    public function update(UserPolicy $user, Education $education)
    {
        if ($user->canDo('education.education.edit') && $user->isAdmin()) {
            return true;
        }

        return $education->user_id == user_id() && $education->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given education.
     *
     * @param UserPolicy $user
     * @param Education $education
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Education $education)
    {
        return $education->user_id == user_id() && $education->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given education.
     *
     * @param UserPolicy $user
     * @param Education $education
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Education $education)
    {
        if ($user->canDo('education.education.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given education.
     *
     * @param UserPolicy $user
     * @param Education $education
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Education $education)
    {
        if ($user->canDo('education.education.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
