<?php

namespace Boomee\Education\Providers;

use Illuminate\Support\ServiceProvider;

class EducationServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = false;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        // Load view
        $this->loadViewsFrom(__DIR__ . '/../../resources/views', 'education');

        // Load translation
        $this->loadTranslationsFrom(__DIR__ . '/../../resources/lang', 'education');

        // Load migrations
        $this->loadMigrationsFrom(__DIR__ . '/../../database/migrations');

        // Call pblish redources function
        $this->publishResources();

    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        $this->mergeConfig();
        $this->registerEducation();
        $this->registerFacade();
        $this->registerBindings();
        //$this->registerCommands();
    }


    /**
     * Register the application bindings.
     *
     * @return void
     */
    protected function registerEducation()
    {
        $this->app->bind('education', function($app) {
            return new Education($app);
        });
    }

    /**
     * Register the vault facade without the user having to add it to the app.php file.
     *
     * @return void
     */
    public function registerFacade() {
        $this->app->booting(function()
        {
            $loader = \Illuminate\Foundation\AliasLoader::getInstance();
            $loader->alias('Education', 'Lavalite\Education\Facades\Education');
        });
    }

    /**
     * Register bindings for the provider.
     *
     * @return void
     */
    public function registerBindings() {
        // Bind facade
        $this->app->bind('boomee.education', function ($app) {
            return $this->app->make('Boomee\Education\Education');
        });

        // Bind Education to repository
        $this->app->bind(
            'Boomee\Education\Interfaces\EducationRepositoryInterface',
            \Boomee\Education\Repositories\Eloquent\EducationRepository::class
        );
        // Bind Deal to repository
        $this->app->bind(
            'Boomee\Education\Interfaces\DealRepositoryInterface',
            \Boomee\Education\Repositories\Eloquent\DealRepository::class
        );

        $this->app->register(\Boomee\Education\Providers\AuthServiceProvider::class);
        
        $this->app->register(\Boomee\Education\Providers\RouteServiceProvider::class);
            }

    /**
     * Merges user's and education's configs.
     *
     * @return void
     */
    protected function mergeConfig()
    {
        $this->mergeConfigFrom(
            __DIR__ . '/../../config/config.php', 'boomee.education'
        );
    }

    /**
     * Register scaffolding command
     */
    protected function registerCommands()
    {
        if ($this->app->runningInConsole()) {
            $this->commands([
                Commands\MakeEducation::class,
            ]);
        }
    }
    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return ['boomee.education'];
    }

    /**
     * Publish resources.
     *
     * @return void
     */
    private function publishResources()
    {
        // Publish configuration file
        $this->publishes([__DIR__ . '/../../config/config.php' => config_path('boomee/education.php')], 'config');

        // Publish admin view
        $this->publishes([__DIR__ . '/../../resources/views' => base_path('resources/views/vendor/education')], 'view');

        // Publish language files
        $this->publishes([__DIR__ . '/../../resources/lang' => base_path('resources/lang/vendor/education')], 'lang');

        // Publish public files and assets.
        $this->publishes([__DIR__ . '/public/' => public_path('/')], 'public');
    }
}
